<?php
// show details of control
// $Id: control.php,v 2.4 2005/02/24 17:04:00 turbo Exp $
//
require("./include/pql_config.inc");
include($_SESSION["path"]."/header.html");
?>
<span class="title1">Server Control</span>
<br>
<br>
Here you can manage a qmail-ldap/control enabled server. The attributes are categorized which is shown
in the navigation bar below control. q-l stands for qmail-ldap.
<br>
<br>

</body>
</html>
